clear
clc
close all hidden

mass_transport_property = 'm';
% mass_transport_property = 'kappa';

descriptor_sets = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12];
number_of_descriptor_sets = numel(descriptor_sets);

folder_training_results = ['training_results_' mass_transport_property];
folder_trained_models = ['trained_models_' mass_transport_property];

% Loop through descriptor sets.
for current_descriptor_set = 1:number_of_descriptor_sets
    disp(['Descriptor set ' num2str(descriptor_sets(current_descriptor_set)) '...'])
    
    files = dir([folder_training_results '/' 'descriptor_set_' num2str(descriptor_sets(current_descriptor_set)) '/' '*.csv']);
    number_of_runs = numel(files);
    disp(['   Found ' num2str(number_of_runs) ' runs...'])

    training_loss = cell(1, number_of_runs);
    validation_loss = cell(1, number_of_runs);

    % Loop through runs.
    for current_run = 1:number_of_runs
        file_name_base = files(current_run).name(1:end-11);
        file_path_losses = [folder_training_results '/' 'descriptor_set_' num2str(descriptor_sets(current_descriptor_set)) '/' file_name_base '_losses.csv'];

        % Read losses.
        losses = readmatrix(file_path_losses);
        try
            training_loss{current_run} = losses(:, 2);
            validation_loss{current_run} = losses(:, 4);
        catch
            training_loss{current_run} = nan;
            validation_loss{current_run} = nan;
        end

    end
    
    min_validation_loss = zeros(1, number_of_runs);
    ind_validation_loss = zeros(1, number_of_runs);

    for current_run = 1:number_of_runs
        [val, ind] = min(validation_loss{current_run});
        min_validation_loss(current_run) = val;
        ind_validation_loss(current_run) = ind;    
    end

    [~, ind] = sort(min_validation_loss, 'ascend');
    
    % Copy best model.
    disp('   Copying best model...')
    file_name_base = files(ind(1)).name(1:end-11);
    
    file_path_source = [folder_training_results '/' 'descriptor_set_' num2str(descriptor_sets(current_descriptor_set)) '/' file_name_base '_model.hdf5'];
    file_path_destination = [folder_trained_models '/' 'model_' num2str(descriptor_sets(current_descriptor_set)) '.hdf5'];
    copyfile(file_path_source, file_path_destination);
    
    file_path_source = [folder_training_results '/' 'descriptor_set_' num2str(descriptor_sets(current_descriptor_set)) '/' file_name_base '_losses.csv'];
    file_path_destination = [folder_trained_models '/' 'losses_' num2str(descriptor_sets(current_descriptor_set)) '.csv'];
    copyfile(file_path_source, file_path_destination);
    
    file_path_source = [folder_training_results '/' 'descriptor_set_' num2str(descriptor_sets(current_descriptor_set)) '/' file_name_base '_parameters.dat'];
    file_path_destination = [folder_trained_models '/' 'parameters_' num2str(descriptor_sets(current_descriptor_set)) '.dat'];
    copyfile(file_path_source, file_path_destination);
end