clear
clc
close all hidden

mass_transport_property = 'm';
% mass_transport_property = 'kappa';

number_of_samples_train = 63000;
number_of_samples_val = 13500;
number_of_samples_test = 13500;

%% Load true values.

folder_data = '../data';

file_id = fopen([folder_data '/' mass_transport_property '_train.bin'], 'r');
y_train = fread(file_id, number_of_samples_train, 'float32');

file_id = fopen([folder_data '/' mass_transport_property '_val.bin'], 'r');
y_val = fread(file_id, number_of_samples_val, 'float32');

file_id = fopen([folder_data '/' mass_transport_property '_test.bin'], 'r');
y_test = fread(file_id, number_of_samples_test, 'float32');

clear file_id

switch mass_transport_property
    case 'm'
        y_train = log(y_train ./ (1 - y_train));
        y_val = log(y_val ./ (1 - y_val));
        y_test = log(y_test ./ (1 - y_test));
    case 'kappa'
        y_train = log(y_train);
        y_val = log(y_val);
        y_test = log(y_test);
end

%% Load predictions.

folder_predictions = ['predictions_' mass_transport_property];

descriptor_sets = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12];
number_of_descriptor_sets = numel(descriptor_sets);

y_train_hat = cell(number_of_descriptor_sets, 1);
y_val_hat = cell(number_of_descriptor_sets, 1);
y_test_hat = cell(number_of_descriptor_sets, 1);

for current_descriptor_set = 1:number_of_descriptor_sets
    file_id = fopen([folder_predictions '/' 'y_train_hat_' num2str(descriptor_sets(current_descriptor_set)) '.bin'], 'r');
    y_train_hat{current_descriptor_set} = fread(file_id, number_of_samples_train, 'float32');
    
    file_id = fopen([folder_predictions '/' 'y_val_hat_' num2str(descriptor_sets(current_descriptor_set)) '.bin'], 'r');
    y_val_hat{current_descriptor_set} = fread(file_id, number_of_samples_val, 'float32');
    
    file_id = fopen([folder_predictions '/' 'y_test_hat_' num2str(descriptor_sets(current_descriptor_set)) '.bin'], 'r');
    y_test_hat{current_descriptor_set} = fread(file_id, number_of_samples_test, 'float32');
end

clear file_id

%% Save results.

save(['results_' mass_transport_property '.mat'],   'y_train', 'y_val', 'y_test', ...
                                                    'y_train_hat', 'y_val_hat', 'y_test_hat', ...
                                                    '-v7');