clear
clc
close all hidden

format long

number_of_samples_train = 63000;
number_of_samples_val = 13500;
number_of_samples_test = 13500;

number_of_descriptor_sets = 12;

%% Load results.

load('results_kappa.mat');

%% Linear scale.

kappa_train = exp(y_train);
kappa_val = exp(y_val);
kappa_test = exp(y_test);

kappa_train_hat = cell(number_of_descriptor_sets, 1);
kappa_val_hat = cell(number_of_descriptor_sets, 1);
kappa_test_hat = cell(number_of_descriptor_sets, 1);

for current_descriptor_set = 1:number_of_descriptor_sets
    kappa_train_hat{current_descriptor_set} = exp(y_train_hat{current_descriptor_set});
    kappa_val_hat{current_descriptor_set} = exp(y_val_hat{current_descriptor_set});
    kappa_test_hat{current_descriptor_set} = exp(y_test_hat{current_descriptor_set});
end

%% Compute MSE at log scale.

mse_train = cell(number_of_descriptor_sets, 1);
mse_val = cell(number_of_descriptor_sets, 1);
mse_test = cell(number_of_descriptor_sets, 1);

for current_descriptor_set = 1:number_of_descriptor_sets
    mse_train{current_descriptor_set} = mean( (y_train_hat{current_descriptor_set} - y_train).^2 );
    mse_val{current_descriptor_set} = mean( (y_val_hat{current_descriptor_set} - y_val).^2 );
    mse_test{current_descriptor_set} = mean( (y_test_hat{current_descriptor_set} - y_test).^2 );
end

%% Compute MAPE at linear scale.

mape_train = cell(number_of_descriptor_sets, 1);
mape_val = cell(number_of_descriptor_sets, 1);
mape_test = cell(number_of_descriptor_sets, 1);

for current_descriptor_set = 1:number_of_descriptor_sets
    mape_train{current_descriptor_set} = 100 * mean( abs(kappa_train_hat{current_descriptor_set} - kappa_train) ./ kappa_train );
    mape_val{current_descriptor_set} = 100 * mean( abs(kappa_val_hat{current_descriptor_set} - kappa_val) ./ kappa_val );
    mape_test{current_descriptor_set} = 100 * mean( abs(kappa_test_hat{current_descriptor_set} - kappa_test) ./ kappa_test );
end

%% Print out MSE and MAE.

for current_descriptor_set = 1:number_of_descriptor_sets
    str = sprintf('%d & %1.4f & %1.4f & %1.4f & %1.2f ', current_descriptor_set,    mse_train{current_descriptor_set}, ...
                                                                                    mse_val{current_descriptor_set}, ...
                                                                                    mse_test{current_descriptor_set}, ...
                                                                                    mape_test{current_descriptor_set});
    disp(str)
end